@@ -1,18 +1,21 @@
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -21,8 +24,7 @@
 #include "ephy-sqlite-connection.h"
 #include <sqlite3.h>
 
-enum
-{
+enum {
   PROP_0,
   PROP_PREPARED_STATEMENT,
   PROP_CONNECTION,
@@ -40,7 +42,10 @@ struct _EphySQLiteStatement {
 G_DEFINE_TYPE (EphySQLiteStatement, ephy_sqlite_statement, G_TYPE_OBJECT);
 
 static void
-ephy_sqlite_statement_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec)
+ephy_sqlite_statement_set_property (GObject      *object,
+                                    guint         property_id,
+                                    const GValue *value,
+                                    GParamSpec   *pspec)
 {
   EphySQLiteStatement *self = EPHY_SQLITE_STATEMENT (object);
 
@@ -84,14 +89,12 @@ ephy_sqlite_statement_class_init (EphySQLiteStatementClass *klass)
 
   obj_properties[PROP_PREPARED_STATEMENT] =
     g_param_spec_pointer ("prepared-statement",
-                          "Prepared statement",
-                          "The statement's backing SQLite prepared statement",
+                          NULL, NULL,
                           G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
   obj_properties[PROP_CONNECTION] =
     g_param_spec_object ("connection",
-                         "Connection",
-                         "The statement's backing SQLite connection",
+                         NULL, NULL,
                          EPHY_TYPE_SQLITE_CONNECTION,
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
@@ -106,7 +109,9 @@ ephy_sqlite_statement_init (EphySQLiteStatement *self)
 }
 
 gboolean
-ephy_sqlite_statement_bind_null (EphySQLiteStatement *self, int column, GError **error)
+ephy_sqlite_statement_bind_null (EphySQLiteStatement  *self,
+                                 int                   column,
+                                 GError              **error)
 {
   if (sqlite3_bind_null (self->prepared_statement, column) != SQLITE_OK) {
     ephy_sqlite_connection_get_error (self->connection, error);
@@ -117,7 +122,10 @@ ephy_sqlite_statement_bind_null (EphySQLiteStatement *self, int column, GError *
 }
 
 gboolean
-ephy_sqlite_statement_bind_boolean (EphySQLiteStatement *self, int column, gboolean value, GError **error)
+ephy_sqlite_statement_bind_boolean (EphySQLiteStatement  *self,
+                                    int                   column,
+                                    gboolean              value,
+                                    GError              **error)
 {
   if (sqlite3_bind_int (self->prepared_statement, column + 1, value ? 1 : 0) != SQLITE_OK) {
     ephy_sqlite_connection_get_error (self->connection, error);
@@ -128,7 +136,10 @@ ephy_sqlite_statement_bind_boolean (EphySQLiteStatement *self, int column, gbool
 }
 
 gboolean
-ephy_sqlite_statement_bind_int (EphySQLiteStatement *self, int column, int value, GError **error)
+ephy_sqlite_statement_bind_int (EphySQLiteStatement  *self,
+                                int                   column,
+                                int                   value,
+                                GError              **error)
 {
   if (sqlite3_bind_int (self->prepared_statement, column + 1, value) != SQLITE_OK) {
     ephy_sqlite_connection_get_error (self->connection, error);
@@ -139,7 +150,24 @@ ephy_sqlite_statement_bind_int (EphySQLiteStatement *self, int column, int value
 }
 
 gboolean
-ephy_sqlite_statement_bind_double (EphySQLiteStatement *self, int column, double value, GError **error)
+ephy_sqlite_statement_bind_int64 (EphySQLiteStatement  *self,
+                                  int                   column,
+                                  gint64                value,
+                                  GError              **error)
+{
+  if (sqlite3_bind_int64 (self->prepared_statement, column + 1, value) != SQLITE_OK) {
+    ephy_sqlite_connection_get_error (self->connection, error);
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
+gboolean
+ephy_sqlite_statement_bind_double (EphySQLiteStatement  *self,
+                                   int                   column,
+                                   double                value,
+                                   GError              **error)
 {
   if (sqlite3_bind_double (self->prepared_statement, column + 1, value) != SQLITE_OK) {
     ephy_sqlite_connection_get_error (self->connection, error);
@@ -150,7 +178,10 @@ ephy_sqlite_statement_bind_double (EphySQLiteStatement *self, int column, double
 }
 
 gboolean
-ephy_sqlite_statement_bind_string (EphySQLiteStatement *self, int column, const char *value, GError **error)
+ephy_sqlite_statement_bind_string (EphySQLiteStatement  *self,
+                                   int                   column,
+                                   const char           *value,
+                                   GError              **error)
 {
   if (sqlite3_bind_text (self->prepared_statement, column + 1, value, -1, SQLITE_TRANSIENT) != SQLITE_OK) {
     ephy_sqlite_connection_get_error (self->connection, error);
@@ -161,7 +192,11 @@ ephy_sqlite_statement_bind_string (EphySQLiteStatement *self, int column, const
 }
 
 gboolean
-ephy_sqlite_statement_bind_blob (EphySQLiteStatement *self, int column, const void *value, int length, GError **error)
+ephy_sqlite_statement_bind_blob (EphySQLiteStatement  *self,
+                                 int                   column,
+                                 const void           *value,
+                                 int                   length,
+                                 GError              **error)
 {
   if (sqlite3_bind_blob (self->prepared_statement, column + 1, value, length, SQLITE_TRANSIENT) != SQLITE_OK) {
     ephy_sqlite_connection_get_error (self->connection, error);
@@ -171,7 +206,8 @@ ephy_sqlite_statement_bind_blob (EphySQLiteStatement *self, int column, const vo
 }
 
 gboolean
-ephy_sqlite_statement_step (EphySQLiteStatement *self, GError **error)
+ephy_sqlite_statement_step (EphySQLiteStatement  *self,
+                            GError              **error)
 {
   int error_code = sqlite3_step (self->prepared_statement);
   if (error_code != SQLITE_OK && error_code != SQLITE_ROW && error_code != SQLITE_DONE) {
@@ -194,7 +230,8 @@ ephy_sqlite_statement_get_column_count (EphySQLiteStatement *self)
 }
 
 EphySQLiteColumnType
-ephy_sqlite_statement_get_column_type (EphySQLiteStatement *self, int column)
+ephy_sqlite_statement_get_column_type (EphySQLiteStatement *self,
+                                       int                  column)
 {
   int column_type = sqlite3_column_type (self->prepared_statement, column);
   switch (column_type) {
@@ -213,37 +250,50 @@ ephy_sqlite_statement_get_column_type (EphySQLiteStatement *self, int column)
 }
 
 int
-ephy_sqlite_statement_get_column_size (EphySQLiteStatement *self, int column)
+ephy_sqlite_statement_get_column_size (EphySQLiteStatement *self,
+                                       int                  column)
 {
   return sqlite3_column_bytes (self->prepared_statement, column);
 }
 
 int
-ephy_sqlite_statement_get_column_as_boolean (EphySQLiteStatement *self, int column)
+ephy_sqlite_statement_get_column_as_boolean (EphySQLiteStatement *self,
+                                             int                  column)
 {
   return ephy_sqlite_statement_get_column_as_int (self, column);
 }
 
 int
-ephy_sqlite_statement_get_column_as_int (EphySQLiteStatement *self, int column)
+ephy_sqlite_statement_get_column_as_int (EphySQLiteStatement *self,
+                                         int                  column)
 {
   return sqlite3_column_int (self->prepared_statement, column);
 }
 
+gint64
+ephy_sqlite_statement_get_column_as_int64 (EphySQLiteStatement *self,
+                                           int                  column)
+{
+  return sqlite3_column_int64 (self->prepared_statement, column);
+}
+
 double
-ephy_sqlite_statement_get_column_as_double (EphySQLiteStatement *self, int column)
+ephy_sqlite_statement_get_column_as_double (EphySQLiteStatement *self,
+                                            int                  column)
 {
   return sqlite3_column_double (self->prepared_statement, column);
 }
 
-const char*
-ephy_sqlite_statement_get_column_as_string (EphySQLiteStatement *self, int column)
+const char *
+ephy_sqlite_statement_get_column_as_string (EphySQLiteStatement *self,
+                                            int                  column)
 {
-  return (const char*) sqlite3_column_text (self->prepared_statement, column);
+  return (const char *)sqlite3_column_text (self->prepared_statement, column);
 }
 
-const void*
-ephy_sqlite_statement_get_column_as_blob (EphySQLiteStatement *self, int column)
+const void *
+ephy_sqlite_statement_get_column_as_blob (EphySQLiteStatement *self,
+                                          int                  column)
 {
   return sqlite3_column_blob (self->prepared_statement, column);
 }
